@@ -1,10 +1,9 @@
-
 import kubify.src.core.file_utils as module_0
 
 
 def test_case_0():
     try:
-        str_0 = '4;]#qWi!#pCm9(CM1\x0bJt'
+        str_0 = "4;]#qWi!#pCm9(CM1\x0bJt"
         list_0 = None
         module_0.copy_file(str_0, list_0)
     except BaseException:
